Module error

Module error 

Error types for Passless

This module defines all error types used in the Passless authenticator. We use thiserror for structured error handling with proper error context.

Enums

Error
Passless-specific errors

Type Aliases

Result
Result type alias using PasslessError